<h1 align="center">Aquiles-Image</h1>

<div align="center">
  <img src="aquilesimage/static/aquilesim.png" alt="Aquiles-Image Logo" width="225"/>
</div>

<p align="center">
  <strong>Easy, fast and cheap Diffusion Models that work for everyone.</strong><br/>
  🚀 FastAPI • Diffusers • Compatible with the OpenAI client
</p>